A package for converting between attitude representations: DCM, Euler angles, Quaternions, and Euler vectors.
Plus conversion between 2 Euler angle set types (xyx, yzy, zxz, xzx, yxy, zyz, xyz, yzx, zxy, xzy, yxz, zyx).
Fully vectorized code, with warnings/errors for Euler angles (singularity, out of range, invalid angle order),
DCM (orthogonality, not proper, exceeded tolerance to unity determinant) and Euler vectors(not unity).

